@@ -7,6 +7,7 @@ __all__ = ["config"]
 config = Config({
     "debug" : {
         "debug_skips" : False // Doc("Enter pdb also for SkipTest exceptions"),
+        "debug_hooks" : False // Doc("Enter pdb also for every exception encountered in a hook/callback"),
         "enabled" : False // Doc("Enter pdb on failures and errors") // Cmdline(on="--pdb"),
     },
     "log" : {
@@ -20,7 +21,6 @@ config = Config({
     },
     "run" : {
         "default_sources": [] // Doc("Default tests to run assuming no other sources are given to the runner"),
-        "local_customization_file_path": "./.slashrc",
         "stop_on_error" : False // Doc("Stop execution when a test doesn't succeed") // Cmdline(on="-x"),
         "session_state_path": "~/.slash/last_session" // Doc("Where to keep last session serialized data"),
         "user_customization_file_path": "~/.slash/slashrc",
